@@ -13,10 +13,11 @@ class Header(Parameter):
        (for example, [`style`](#parameterStyle)).
     """
 
-    name = Field(default="", const="")
-    param_in = Field(default="header", const="header", alias="in")
+    name = Field(default="", const=True)
+    param_in = Field(default="header", const=True, alias="in")
 
     class Config:
+        allow_population_by_field_name = True,
         schema_extra = {
             "examples": [
                 {"description": "The number of allowed requests in the current period", "schema": {"type": "integer"}}
